# -*- coding: utf-8 -*-

"""
Python Encoder
~~~~~~~~~~~~~~~~~~~

A basic wrapper for the Discord API.

:copyright: (c) 2022-present D1ffic00lt
:license: MIT, see LICENSE for more details.

"""

from textbytesencoder.textbytesencoder import *

__version__ = "0.1.4"
__title__ = 'Encoder'
__author__ = "D1ffic00lt"
__copyright__ = "Copyright 2013-2022 {}".format(__author__)
